# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/ratelimit/v3/rls.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import config_source_pb2 as envoy_dot_config_dot_core_dot_v3_dot_config__source__pb2
from envoy.config.core.v3 import grpc_service_pb2 as envoy_dot_config_dot_core_dot_v3_dot_grpc__service__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/ratelimit/v3/rls.proto',
  package='envoy.config.ratelimit.v3',
  syntax='proto3',
  serialized_options=b'\n\'io.envoyproxy.envoy.config.ratelimit.v3B\010RlsProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#envoy/config/ratelimit/v3/rls.proto\x12\x19\x65nvoy.config.ratelimit.v3\x1a(envoy/config/core/v3/config_source.proto\x1a\'envoy/config/core/v3/grpc_service.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xeb\x01\n\x16RateLimitServiceConfig\x12\x41\n\x0cgrpc_service\x18\x02 \x01(\x0b\x32!.envoy.config.core.v3.GrpcServiceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12I\n\x15transport_api_version\x18\x04 \x01(\x0e\x32 .envoy.config.core.v3.ApiVersionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01:7\x9a\xc5\x88\x1e\x32\n0envoy.config.ratelimit.v2.RateLimitServiceConfigJ\x04\x08\x01\x10\x02J\x04\x08\x03\x10\x04\x42=\n\'io.envoyproxy.envoy.config.ratelimit.v3B\x08RlsProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_config__source__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v3_dot_grpc__service__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_RATELIMITSERVICECONFIG = _descriptor.Descriptor(
  name='RateLimitServiceConfig',
  full_name='envoy.config.ratelimit.v3.RateLimitServiceConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='grpc_service', full_name='envoy.config.ratelimit.v3.RateLimitServiceConfig.grpc_service', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transport_api_version', full_name='envoy.config.ratelimit.v3.RateLimitServiceConfig.transport_api_version', index=1,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0362\n0envoy.config.ratelimit.v2.RateLimitServiceConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=241,
  serialized_end=476,
)

_RATELIMITSERVICECONFIG.fields_by_name['grpc_service'].message_type = envoy_dot_config_dot_core_dot_v3_dot_grpc__service__pb2._GRPCSERVICE
_RATELIMITSERVICECONFIG.fields_by_name['transport_api_version'].enum_type = envoy_dot_config_dot_core_dot_v3_dot_config__source__pb2._APIVERSION
DESCRIPTOR.message_types_by_name['RateLimitServiceConfig'] = _RATELIMITSERVICECONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RateLimitServiceConfig = _reflection.GeneratedProtocolMessageType('RateLimitServiceConfig', (_message.Message,), {
  'DESCRIPTOR' : _RATELIMITSERVICECONFIG,
  '__module__' : 'envoy.config.ratelimit.v3.rls_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.ratelimit.v3.RateLimitServiceConfig)
  })
_sym_db.RegisterMessage(RateLimitServiceConfig)


DESCRIPTOR._options = None
_RATELIMITSERVICECONFIG.fields_by_name['grpc_service']._options = None
_RATELIMITSERVICECONFIG.fields_by_name['transport_api_version']._options = None
_RATELIMITSERVICECONFIG._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/listener/v3/listener_components.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import address_pb2 as envoy_dot_config_dot_core_dot_v3_dot_address__pb2
from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from envoy.type.v3 import range_pb2 as envoy_dot_type_dot_v3_dot_range__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/listener/v3/listener_components.proto',
  package='envoy.config.listener.v3',
  syntax='proto3',
  serialized_options=b'\n&io.envoyproxy.envoy.config.listener.v3B\027ListenerComponentsProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n2envoy/config/listener/v3/listener_components.proto\x12\x18\x65nvoy.config.listener.v3\x1a\"envoy/config/core/v3/address.proto\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a$envoy/config/core/v3/extension.proto\x1a\x19\x65nvoy/type/v3/range.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xde\x01\n\x06\x46ilter\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12,\n\x0ctyped_config\x18\x04 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x12G\n\x10\x63onfig_discovery\x18\x05 \x01(\x0b\x32+.envoy.config.core.v3.ExtensionConfigSourceH\x00:#\x9a\xc5\x88\x1e\x1e\n\x1c\x65nvoy.api.v2.listener.FilterB\r\n\x0b\x63onfig_typeJ\x04\x08\x03\x10\x04J\x04\x08\x02\x10\x03R\x06\x63onfig\"\xee\x04\n\x10\x46ilterChainMatch\x12\x43\n\x10\x64\x65stination_port\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0b\xfa\x42\x08*\x06\x18\xff\xff\x03(\x01\x12\x36\n\rprefix_ranges\x18\x03 \x03(\x0b\x32\x1f.envoy.config.core.v3.CidrRange\x12\x16\n\x0e\x61\x64\x64ress_suffix\x18\x04 \x01(\t\x12\x30\n\nsuffix_len\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12^\n\x0bsource_type\x18\x0c \x01(\x0e\x32?.envoy.config.listener.v3.FilterChainMatch.ConnectionSourceTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12=\n\x14source_prefix_ranges\x18\x06 \x03(\x0b\x32\x1f.envoy.config.core.v3.CidrRange\x12&\n\x0csource_ports\x18\x07 \x03(\rB\x10\xfa\x42\r\x92\x01\n\"\x08*\x06\x18\xff\xff\x03(\x01\x12\x14\n\x0cserver_names\x18\x0b \x03(\t\x12\x1a\n\x12transport_protocol\x18\t \x01(\t\x12\x1d\n\x15\x61pplication_protocols\x18\n \x03(\t\"F\n\x14\x43onnectionSourceType\x12\x07\n\x03\x41NY\x10\x00\x12\x17\n\x13SAME_IP_OR_LOOPBACK\x10\x01\x12\x0c\n\x08\x45XTERNAL\x10\x02:-\x9a\xc5\x88\x1e(\n&envoy.api.v2.listener.FilterChainMatchJ\x04\x08\x01\x10\x02\"\xef\x04\n\x0b\x46ilterChain\x12\x46\n\x12\x66ilter_chain_match\x18\x01 \x01(\x0b\x32*.envoy.config.listener.v3.FilterChainMatch\x12\x31\n\x07\x66ilters\x18\x03 \x03(\x0b\x32 .envoy.config.listener.v3.Filter\x12\x37\n\x0fuse_proxy_proto\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x02\x18\x01\x12\x30\n\x08metadata\x18\x05 \x01(\x0b\x32\x1e.envoy.config.core.v3.Metadata\x12?\n\x10transport_socket\x18\x06 \x01(\x0b\x32%.envoy.config.core.v3.TransportSocket\x12\x43\n transport_socket_connect_timeout\x18\t \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\\\n\x17on_demand_configuration\x18\x08 \x01(\x0b\x32;.envoy.config.listener.v3.FilterChain.OnDemandConfiguration\x1aK\n\x15OnDemandConfiguration\x12\x32\n\x0frebuild_timeout\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration:(\x9a\xc5\x88\x1e#\n!envoy.api.v2.listener.FilterChainJ\x04\x08\x02\x10\x03R\x0btls_context\"\xfe\x04\n!ListenerFilterChainMatchPredicate\x12X\n\x08or_match\x18\x01 \x01(\x0b\x32\x44.envoy.config.listener.v3.ListenerFilterChainMatchPredicate.MatchSetH\x00\x12Y\n\tand_match\x18\x02 \x01(\x0b\x32\x44.envoy.config.listener.v3.ListenerFilterChainMatchPredicate.MatchSetH\x00\x12P\n\tnot_match\x18\x03 \x01(\x0b\x32;.envoy.config.listener.v3.ListenerFilterChainMatchPredicateH\x00\x12\x1c\n\tany_match\x18\x04 \x01(\x08\x42\x07\xfa\x42\x04j\x02\x08\x01H\x00\x12;\n\x16\x64\x65stination_port_range\x18\x05 \x01(\x0b\x32\x19.envoy.type.v3.Int32RangeH\x00\x1a\xa9\x01\n\x08MatchSet\x12T\n\x05rules\x18\x01 \x03(\x0b\x32;.envoy.config.listener.v3.ListenerFilterChainMatchPredicateB\x08\xfa\x42\x05\x92\x01\x02\x08\x02:G\x9a\xc5\x88\x1e\x42\n@envoy.api.v2.listener.ListenerFilterChainMatchPredicate.MatchSet:>\x9a\xc5\x88\x1e\x39\n7envoy.api.v2.listener.ListenerFilterChainMatchPredicateB\x0b\n\x04rule\x12\x03\xf8\x42\x01\"\xf5\x01\n\x0eListenerFilter\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x12T\n\x0f\x66ilter_disabled\x18\x04 \x01(\x0b\x32;.envoy.config.listener.v3.ListenerFilterChainMatchPredicate:+\x9a\xc5\x88\x1e&\n$envoy.api.v2.listener.ListenerFilterB\r\n\x0b\x63onfig_typeJ\x04\x08\x02\x10\x03R\x06\x63onfigBK\n&io.envoyproxy.envoy.config.listener.v3B\x17ListenerComponentsProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_address__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v3_dot_base__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v3_dot_extension__pb2.DESCRIPTOR,envoy_dot_type_dot_v3_dot_range__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_FILTERCHAINMATCH_CONNECTIONSOURCETYPE = _descriptor.EnumDescriptor(
  name='ConnectionSourceType',
  full_name='envoy.config.listener.v3.FilterChainMatch.ConnectionSourceType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ANY', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SAME_IP_OR_LOOPBACK', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXTERNAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1121,
  serialized_end=1191,
)
_sym_db.RegisterEnumDescriptor(_FILTERCHAINMATCH_CONNECTIONSOURCETYPE)


_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='envoy.config.listener.v3.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.listener.v3.Filter.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_config', full_name='envoy.config.listener.v3.Filter.typed_config', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config_discovery', full_name='envoy.config.listener.v3.Filter.config_discovery', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\036\n\034envoy.api.v2.listener.Filter',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config_type', full_name='envoy.config.listener.v3.Filter.config_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=397,
  serialized_end=619,
)


_FILTERCHAINMATCH = _descriptor.Descriptor(
  name='FilterChainMatch',
  full_name='envoy.config.listener.v3.FilterChainMatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='destination_port', full_name='envoy.config.listener.v3.FilterChainMatch.destination_port', index=0,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\010*\006\030\377\377\003(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prefix_ranges', full_name='envoy.config.listener.v3.FilterChainMatch.prefix_ranges', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address_suffix', full_name='envoy.config.listener.v3.FilterChainMatch.address_suffix', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='suffix_len', full_name='envoy.config.listener.v3.FilterChainMatch.suffix_len', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_type', full_name='envoy.config.listener.v3.FilterChainMatch.source_type', index=4,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_prefix_ranges', full_name='envoy.config.listener.v3.FilterChainMatch.source_prefix_ranges', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_ports', full_name='envoy.config.listener.v3.FilterChainMatch.source_ports', index=6,
      number=7, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\r\222\001\n\"\010*\006\030\377\377\003(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_names', full_name='envoy.config.listener.v3.FilterChainMatch.server_names', index=7,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transport_protocol', full_name='envoy.config.listener.v3.FilterChainMatch.transport_protocol', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='application_protocols', full_name='envoy.config.listener.v3.FilterChainMatch.application_protocols', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FILTERCHAINMATCH_CONNECTIONSOURCETYPE,
  ],
  serialized_options=b'\232\305\210\036(\n&envoy.api.v2.listener.FilterChainMatch',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=622,
  serialized_end=1244,
)


_FILTERCHAIN_ONDEMANDCONFIGURATION = _descriptor.Descriptor(
  name='OnDemandConfiguration',
  full_name='envoy.config.listener.v3.FilterChain.OnDemandConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rebuild_timeout', full_name='envoy.config.listener.v3.FilterChain.OnDemandConfiguration.rebuild_timeout', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1734,
  serialized_end=1809,
)

_FILTERCHAIN = _descriptor.Descriptor(
  name='FilterChain',
  full_name='envoy.config.listener.v3.FilterChain',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter_chain_match', full_name='envoy.config.listener.v3.FilterChain.filter_chain_match', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='envoy.config.listener.v3.FilterChain.filters', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_proxy_proto', full_name='envoy.config.listener.v3.FilterChain.use_proxy_proto', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='envoy.config.listener.v3.FilterChain.metadata', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transport_socket', full_name='envoy.config.listener.v3.FilterChain.transport_socket', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transport_socket_connect_timeout', full_name='envoy.config.listener.v3.FilterChain.transport_socket_connect_timeout', index=5,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.listener.v3.FilterChain.name', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='on_demand_configuration', full_name='envoy.config.listener.v3.FilterChain.on_demand_configuration', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FILTERCHAIN_ONDEMANDCONFIGURATION, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036#\n!envoy.api.v2.listener.FilterChain',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1247,
  serialized_end=1870,
)


_LISTENERFILTERCHAINMATCHPREDICATE_MATCHSET = _descriptor.Descriptor(
  name='MatchSet',
  full_name='envoy.config.listener.v3.ListenerFilterChainMatchPredicate.MatchSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rules', full_name='envoy.config.listener.v3.ListenerFilterChainMatchPredicate.MatchSet.rules', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036B\n@envoy.api.v2.listener.ListenerFilterChainMatchPredicate.MatchSet',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2265,
  serialized_end=2434,
)

_LISTENERFILTERCHAINMATCHPREDICATE = _descriptor.Descriptor(
  name='ListenerFilterChainMatchPredicate',
  full_name='envoy.config.listener.v3.ListenerFilterChainMatchPredicate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='or_match', full_name='envoy.config.listener.v3.ListenerFilterChainMatchPredicate.or_match', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='and_match', full_name='envoy.config.listener.v3.ListenerFilterChainMatchPredicate.and_match', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='not_match', full_name='envoy.config.listener.v3.ListenerFilterChainMatchPredicate.not_match', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='any_match', full_name='envoy.config.listener.v3.ListenerFilterChainMatchPredicate.any_match', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004j\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_port_range', full_name='envoy.config.listener.v3.ListenerFilterChainMatchPredicate.destination_port_range', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTENERFILTERCHAINMATCHPREDICATE_MATCHSET, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0369\n7envoy.api.v2.listener.ListenerFilterChainMatchPredicate',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='rule', full_name='envoy.config.listener.v3.ListenerFilterChainMatchPredicate.rule',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=1873,
  serialized_end=2511,
)


_LISTENERFILTER = _descriptor.Descriptor(
  name='ListenerFilter',
  full_name='envoy.config.listener.v3.ListenerFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.listener.v3.ListenerFilter.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_config', full_name='envoy.config.listener.v3.ListenerFilter.typed_config', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter_disabled', full_name='envoy.config.listener.v3.ListenerFilter.filter_disabled', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036&\n$envoy.api.v2.listener.ListenerFilter',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config_type', full_name='envoy.config.listener.v3.ListenerFilter.config_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2514,
  serialized_end=2759,
)

_FILTER.fields_by_name['typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_FILTER.fields_by_name['config_discovery'].message_type = envoy_dot_config_dot_core_dot_v3_dot_extension__pb2._EXTENSIONCONFIGSOURCE
_FILTER.oneofs_by_name['config_type'].fields.append(
  _FILTER.fields_by_name['typed_config'])
_FILTER.fields_by_name['typed_config'].containing_oneof = _FILTER.oneofs_by_name['config_type']
_FILTER.oneofs_by_name['config_type'].fields.append(
  _FILTER.fields_by_name['config_discovery'])
_FILTER.fields_by_name['config_discovery'].containing_oneof = _FILTER.oneofs_by_name['config_type']
_FILTERCHAINMATCH.fields_by_name['destination_port'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_FILTERCHAINMATCH.fields_by_name['prefix_ranges'].message_type = envoy_dot_config_dot_core_dot_v3_dot_address__pb2._CIDRRANGE
_FILTERCHAINMATCH.fields_by_name['suffix_len'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_FILTERCHAINMATCH.fields_by_name['source_type'].enum_type = _FILTERCHAINMATCH_CONNECTIONSOURCETYPE
_FILTERCHAINMATCH.fields_by_name['source_prefix_ranges'].message_type = envoy_dot_config_dot_core_dot_v3_dot_address__pb2._CIDRRANGE
_FILTERCHAINMATCH_CONNECTIONSOURCETYPE.containing_type = _FILTERCHAINMATCH
_FILTERCHAIN_ONDEMANDCONFIGURATION.fields_by_name['rebuild_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_FILTERCHAIN_ONDEMANDCONFIGURATION.containing_type = _FILTERCHAIN
_FILTERCHAIN.fields_by_name['filter_chain_match'].message_type = _FILTERCHAINMATCH
_FILTERCHAIN.fields_by_name['filters'].message_type = _FILTER
_FILTERCHAIN.fields_by_name['use_proxy_proto'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_FILTERCHAIN.fields_by_name['metadata'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._METADATA
_FILTERCHAIN.fields_by_name['transport_socket'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._TRANSPORTSOCKET
_FILTERCHAIN.fields_by_name['transport_socket_connect_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_FILTERCHAIN.fields_by_name['on_demand_configuration'].message_type = _FILTERCHAIN_ONDEMANDCONFIGURATION
_LISTENERFILTERCHAINMATCHPREDICATE_MATCHSET.fields_by_name['rules'].message_type = _LISTENERFILTERCHAINMATCHPREDICATE
_LISTENERFILTERCHAINMATCHPREDICATE_MATCHSET.containing_type = _LISTENERFILTERCHAINMATCHPREDICATE
_LISTENERFILTERCHAINMATCHPREDICATE.fields_by_name['or_match'].message_type = _LISTENERFILTERCHAINMATCHPREDICATE_MATCHSET
_LISTENERFILTERCHAINMATCHPREDICATE.fields_by_name['and_match'].message_type = _LISTENERFILTERCHAINMATCHPREDICATE_MATCHSET
_LISTENERFILTERCHAINMATCHPREDICATE.fields_by_name['not_match'].message_type = _LISTENERFILTERCHAINMATCHPREDICATE
_LISTENERFILTERCHAINMATCHPREDICATE.fields_by_name['destination_port_range'].message_type = envoy_dot_type_dot_v3_dot_range__pb2._INT32RANGE
_LISTENERFILTERCHAINMATCHPREDICATE.oneofs_by_name['rule'].fields.append(
  _LISTENERFILTERCHAINMATCHPREDICATE.fields_by_name['or_match'])
_LISTENERFILTERCHAINMATCHPREDICATE.fields_by_name['or_match'].containing_oneof = _LISTENERFILTERCHAINMATCHPREDICATE.oneofs_by_name['rule']
_LISTENERFILTERCHAINMATCHPREDICATE.oneofs_by_name['rule'].fields.append(
  _LISTENERFILTERCHAINMATCHPREDICATE.fields_by_name['and_match'])
_LISTENERFILTERCHAINMATCHPREDICATE.fields_by_name['and_match'].containing_oneof = _LISTENERFILTERCHAINMATCHPREDICATE.oneofs_by_name['rule']
_LISTENERFILTERCHAINMATCHPREDICATE.oneofs_by_name['rule'].fields.append(
  _LISTENERFILTERCHAINMATCHPREDICATE.fields_by_name['not_match'])
_LISTENERFILTERCHAINMATCHPREDICATE.fields_by_name['not_match'].containing_oneof = _LISTENERFILTERCHAINMATCHPREDICATE.oneofs_by_name['rule']
_LISTENERFILTERCHAINMATCHPREDICATE.oneofs_by_name['rule'].fields.append(
  _LISTENERFILTERCHAINMATCHPREDICATE.fields_by_name['any_match'])
_LISTENERFILTERCHAINMATCHPREDICATE.fields_by_name['any_match'].containing_oneof = _LISTENERFILTERCHAINMATCHPREDICATE.oneofs_by_name['rule']
_LISTENERFILTERCHAINMATCHPREDICATE.oneofs_by_name['rule'].fields.append(
  _LISTENERFILTERCHAINMATCHPREDICATE.fields_by_name['destination_port_range'])
_LISTENERFILTERCHAINMATCHPREDICATE.fields_by_name['destination_port_range'].containing_oneof = _LISTENERFILTERCHAINMATCHPREDICATE.oneofs_by_name['rule']
_LISTENERFILTER.fields_by_name['typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_LISTENERFILTER.fields_by_name['filter_disabled'].message_type = _LISTENERFILTERCHAINMATCHPREDICATE
_LISTENERFILTER.oneofs_by_name['config_type'].fields.append(
  _LISTENERFILTER.fields_by_name['typed_config'])
_LISTENERFILTER.fields_by_name['typed_config'].containing_oneof = _LISTENERFILTER.oneofs_by_name['config_type']
DESCRIPTOR.message_types_by_name['Filter'] = _FILTER
DESCRIPTOR.message_types_by_name['FilterChainMatch'] = _FILTERCHAINMATCH
DESCRIPTOR.message_types_by_name['FilterChain'] = _FILTERCHAIN
DESCRIPTOR.message_types_by_name['ListenerFilterChainMatchPredicate'] = _LISTENERFILTERCHAINMATCHPREDICATE
DESCRIPTOR.message_types_by_name['ListenerFilter'] = _LISTENERFILTER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Filter = _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
  'DESCRIPTOR' : _FILTER,
  '__module__' : 'envoy.config.listener.v3.listener_components_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.listener.v3.Filter)
  })
_sym_db.RegisterMessage(Filter)

FilterChainMatch = _reflection.GeneratedProtocolMessageType('FilterChainMatch', (_message.Message,), {
  'DESCRIPTOR' : _FILTERCHAINMATCH,
  '__module__' : 'envoy.config.listener.v3.listener_components_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.listener.v3.FilterChainMatch)
  })
_sym_db.RegisterMessage(FilterChainMatch)

FilterChain = _reflection.GeneratedProtocolMessageType('FilterChain', (_message.Message,), {

  'OnDemandConfiguration' : _reflection.GeneratedProtocolMessageType('OnDemandConfiguration', (_message.Message,), {
    'DESCRIPTOR' : _FILTERCHAIN_ONDEMANDCONFIGURATION,
    '__module__' : 'envoy.config.listener.v3.listener_components_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.listener.v3.FilterChain.OnDemandConfiguration)
    })
  ,
  'DESCRIPTOR' : _FILTERCHAIN,
  '__module__' : 'envoy.config.listener.v3.listener_components_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.listener.v3.FilterChain)
  })
_sym_db.RegisterMessage(FilterChain)
_sym_db.RegisterMessage(FilterChain.OnDemandConfiguration)

ListenerFilterChainMatchPredicate = _reflection.GeneratedProtocolMessageType('ListenerFilterChainMatchPredicate', (_message.Message,), {

  'MatchSet' : _reflection.GeneratedProtocolMessageType('MatchSet', (_message.Message,), {
    'DESCRIPTOR' : _LISTENERFILTERCHAINMATCHPREDICATE_MATCHSET,
    '__module__' : 'envoy.config.listener.v3.listener_components_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.listener.v3.ListenerFilterChainMatchPredicate.MatchSet)
    })
  ,
  'DESCRIPTOR' : _LISTENERFILTERCHAINMATCHPREDICATE,
  '__module__' : 'envoy.config.listener.v3.listener_components_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.listener.v3.ListenerFilterChainMatchPredicate)
  })
_sym_db.RegisterMessage(ListenerFilterChainMatchPredicate)
_sym_db.RegisterMessage(ListenerFilterChainMatchPredicate.MatchSet)

ListenerFilter = _reflection.GeneratedProtocolMessageType('ListenerFilter', (_message.Message,), {
  'DESCRIPTOR' : _LISTENERFILTER,
  '__module__' : 'envoy.config.listener.v3.listener_components_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.listener.v3.ListenerFilter)
  })
_sym_db.RegisterMessage(ListenerFilter)


DESCRIPTOR._options = None
_FILTER.fields_by_name['name']._options = None
_FILTER._options = None
_FILTERCHAINMATCH.fields_by_name['destination_port']._options = None
_FILTERCHAINMATCH.fields_by_name['source_type']._options = None
_FILTERCHAINMATCH.fields_by_name['source_ports']._options = None
_FILTERCHAINMATCH._options = None
_FILTERCHAIN.fields_by_name['use_proxy_proto']._options = None
_FILTERCHAIN._options = None
_LISTENERFILTERCHAINMATCHPREDICATE_MATCHSET.fields_by_name['rules']._options = None
_LISTENERFILTERCHAINMATCHPREDICATE_MATCHSET._options = None
_LISTENERFILTERCHAINMATCHPREDICATE.oneofs_by_name['rule']._options = None
_LISTENERFILTERCHAINMATCHPREDICATE.fields_by_name['any_match']._options = None
_LISTENERFILTERCHAINMATCHPREDICATE._options = None
_LISTENERFILTER.fields_by_name['name']._options = None
_LISTENERFILTER._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/compression/gzip/decompressor/v3/gzip.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/compression/gzip/decompressor/v3/gzip.proto',
  package='envoy.extensions.compression.gzip.decompressor.v3',
  syntax='proto3',
  serialized_options=b'\n?io.envoyproxy.envoy.extensions.compression.gzip.decompressor.v3B\tGzipProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n<envoy/extensions/compression/gzip/decompressor/v3/gzip.proto\x12\x31\x65nvoy.extensions.compression.gzip.decompressor.v3\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x84\x01\n\x04Gzip\x12<\n\x0bwindow_bits\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\t\xfa\x42\x06*\x04\x18\x0f(\t\x12>\n\nchunk_size\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0c\xfa\x42\t*\x07\x18\x80\x80\x04(\x80 BV\n?io.envoyproxy.envoy.extensions.compression.gzip.decompressor.v3B\tGzipProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_GZIP = _descriptor.Descriptor(
  name='Gzip',
  full_name='envoy.extensions.compression.gzip.decompressor.v3.Gzip',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='window_bits', full_name='envoy.extensions.compression.gzip.decompressor.v3.Gzip.window_bits', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006*\004\030\017(\t', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chunk_size', full_name='envoy.extensions.compression.gzip.decompressor.v3.Gzip.chunk_size', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\t*\007\030\200\200\004(\200 ', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=204,
  serialized_end=336,
)

_GZIP.fields_by_name['window_bits'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_GZIP.fields_by_name['chunk_size'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
DESCRIPTOR.message_types_by_name['Gzip'] = _GZIP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Gzip = _reflection.GeneratedProtocolMessageType('Gzip', (_message.Message,), {
  'DESCRIPTOR' : _GZIP,
  '__module__' : 'envoy.extensions.compression.gzip.decompressor.v3.gzip_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.compression.gzip.decompressor.v3.Gzip)
  })
_sym_db.RegisterMessage(Gzip)


DESCRIPTOR._options = None
_GZIP.fields_by_name['window_bits']._options = None
_GZIP.fields_by_name['chunk_size']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/type/matcher/value.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.matcher import number_pb2 as envoy_dot_type_dot_matcher_dot_number__pb2
from envoy.type.matcher import string_pb2 as envoy_dot_type_dot_matcher_dot_string__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/type/matcher/value.proto',
  package='envoy.type.matcher',
  syntax='proto3',
  serialized_options=b'\n io.envoyproxy.envoy.type.matcherB\nValueProtoP\001\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1e\x65nvoy/type/matcher/value.proto\x12\x12\x65nvoy.type.matcher\x1a\x1f\x65nvoy/type/matcher/number.proto\x1a\x1f\x65nvoy/type/matcher/string.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xcf\x02\n\x0cValueMatcher\x12@\n\nnull_match\x18\x01 \x01(\x0b\x32*.envoy.type.matcher.ValueMatcher.NullMatchH\x00\x12\x39\n\x0c\x64ouble_match\x18\x02 \x01(\x0b\x32!.envoy.type.matcher.DoubleMatcherH\x00\x12\x39\n\x0cstring_match\x18\x03 \x01(\x0b\x32!.envoy.type.matcher.StringMatcherH\x00\x12\x14\n\nbool_match\x18\x04 \x01(\x08H\x00\x12\x17\n\rpresent_match\x18\x05 \x01(\x08H\x00\x12\x35\n\nlist_match\x18\x06 \x01(\x0b\x32\x1f.envoy.type.matcher.ListMatcherH\x00\x1a\x0b\n\tNullMatchB\x14\n\rmatch_pattern\x12\x03\xf8\x42\x01\"W\n\x0bListMatcher\x12\x32\n\x06one_of\x18\x01 \x01(\x0b\x32 .envoy.type.matcher.ValueMatcherH\x00\x42\x14\n\rmatch_pattern\x12\x03\xf8\x42\x01\x42\x38\n io.envoyproxy.envoy.type.matcherB\nValueProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_type_dot_matcher_dot_number__pb2.DESCRIPTOR,envoy_dot_type_dot_matcher_dot_string__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_VALUEMATCHER_NULLMATCH = _descriptor.Descriptor(
  name='NullMatch',
  full_name='envoy.type.matcher.ValueMatcher.NullMatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=479,
  serialized_end=490,
)

_VALUEMATCHER = _descriptor.Descriptor(
  name='ValueMatcher',
  full_name='envoy.type.matcher.ValueMatcher',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='null_match', full_name='envoy.type.matcher.ValueMatcher.null_match', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='double_match', full_name='envoy.type.matcher.ValueMatcher.double_match', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string_match', full_name='envoy.type.matcher.ValueMatcher.string_match', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bool_match', full_name='envoy.type.matcher.ValueMatcher.bool_match', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='present_match', full_name='envoy.type.matcher.ValueMatcher.present_match', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='list_match', full_name='envoy.type.matcher.ValueMatcher.list_match', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_VALUEMATCHER_NULLMATCH, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='match_pattern', full_name='envoy.type.matcher.ValueMatcher.match_pattern',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=177,
  serialized_end=512,
)


_LISTMATCHER = _descriptor.Descriptor(
  name='ListMatcher',
  full_name='envoy.type.matcher.ListMatcher',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='one_of', full_name='envoy.type.matcher.ListMatcher.one_of', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='match_pattern', full_name='envoy.type.matcher.ListMatcher.match_pattern',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=514,
  serialized_end=601,
)

_VALUEMATCHER_NULLMATCH.containing_type = _VALUEMATCHER
_VALUEMATCHER.fields_by_name['null_match'].message_type = _VALUEMATCHER_NULLMATCH
_VALUEMATCHER.fields_by_name['double_match'].message_type = envoy_dot_type_dot_matcher_dot_number__pb2._DOUBLEMATCHER
_VALUEMATCHER.fields_by_name['string_match'].message_type = envoy_dot_type_dot_matcher_dot_string__pb2._STRINGMATCHER
_VALUEMATCHER.fields_by_name['list_match'].message_type = _LISTMATCHER
_VALUEMATCHER.oneofs_by_name['match_pattern'].fields.append(
  _VALUEMATCHER.fields_by_name['null_match'])
_VALUEMATCHER.fields_by_name['null_match'].containing_oneof = _VALUEMATCHER.oneofs_by_name['match_pattern']
_VALUEMATCHER.oneofs_by_name['match_pattern'].fields.append(
  _VALUEMATCHER.fields_by_name['double_match'])
_VALUEMATCHER.fields_by_name['double_match'].containing_oneof = _VALUEMATCHER.oneofs_by_name['match_pattern']
_VALUEMATCHER.oneofs_by_name['match_pattern'].fields.append(
  _VALUEMATCHER.fields_by_name['string_match'])
_VALUEMATCHER.fields_by_name['string_match'].containing_oneof = _VALUEMATCHER.oneofs_by_name['match_pattern']
_VALUEMATCHER.oneofs_by_name['match_pattern'].fields.append(
  _VALUEMATCHER.fields_by_name['bool_match'])
_VALUEMATCHER.fields_by_name['bool_match'].containing_oneof = _VALUEMATCHER.oneofs_by_name['match_pattern']
_VALUEMATCHER.oneofs_by_name['match_pattern'].fields.append(
  _VALUEMATCHER.fields_by_name['present_match'])
_VALUEMATCHER.fields_by_name['present_match'].containing_oneof = _VALUEMATCHER.oneofs_by_name['match_pattern']
_VALUEMATCHER.oneofs_by_name['match_pattern'].fields.append(
  _VALUEMATCHER.fields_by_name['list_match'])
_VALUEMATCHER.fields_by_name['list_match'].containing_oneof = _VALUEMATCHER.oneofs_by_name['match_pattern']
_LISTMATCHER.fields_by_name['one_of'].message_type = _VALUEMATCHER
_LISTMATCHER.oneofs_by_name['match_pattern'].fields.append(
  _LISTMATCHER.fields_by_name['one_of'])
_LISTMATCHER.fields_by_name['one_of'].containing_oneof = _LISTMATCHER.oneofs_by_name['match_pattern']
DESCRIPTOR.message_types_by_name['ValueMatcher'] = _VALUEMATCHER
DESCRIPTOR.message_types_by_name['ListMatcher'] = _LISTMATCHER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ValueMatcher = _reflection.GeneratedProtocolMessageType('ValueMatcher', (_message.Message,), {

  'NullMatch' : _reflection.GeneratedProtocolMessageType('NullMatch', (_message.Message,), {
    'DESCRIPTOR' : _VALUEMATCHER_NULLMATCH,
    '__module__' : 'envoy.type.matcher.value_pb2'
    # @@protoc_insertion_point(class_scope:envoy.type.matcher.ValueMatcher.NullMatch)
    })
  ,
  'DESCRIPTOR' : _VALUEMATCHER,
  '__module__' : 'envoy.type.matcher.value_pb2'
  # @@protoc_insertion_point(class_scope:envoy.type.matcher.ValueMatcher)
  })
_sym_db.RegisterMessage(ValueMatcher)
_sym_db.RegisterMessage(ValueMatcher.NullMatch)

ListMatcher = _reflection.GeneratedProtocolMessageType('ListMatcher', (_message.Message,), {
  'DESCRIPTOR' : _LISTMATCHER,
  '__module__' : 'envoy.type.matcher.value_pb2'
  # @@protoc_insertion_point(class_scope:envoy.type.matcher.ListMatcher)
  })
_sym_db.RegisterMessage(ListMatcher)


DESCRIPTOR._options = None
_VALUEMATCHER.oneofs_by_name['match_pattern']._options = None
_LISTMATCHER.oneofs_by_name['match_pattern']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/metrics/v2/stats.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import address_pb2 as envoy_dot_api_dot_v2_dot_core_dot_address__pb2
from envoy.type.matcher import string_pb2 as envoy_dot_type_dot_matcher_dot_string__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/metrics/v2/stats.proto',
  package='envoy.config.metrics.v2',
  syntax='proto3',
  serialized_options=b'\n%io.envoyproxy.envoy.config.metrics.v2B\nStatsProtoP\001\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#envoy/config/metrics/v2/stats.proto\x12\x17\x65nvoy.config.metrics.v2\x1a\x1f\x65nvoy/api/v2/core/address.proto\x1a\x1f\x65nvoy/type/matcher/string.proto\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x85\x01\n\tStatsSink\x12\x0c\n\x04name\x18\x01 \x01(\t\x12-\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x02\x18\x01H\x00\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x42\r\n\x0b\x63onfig_type\"\xc0\x01\n\x0bStatsConfig\x12\x39\n\nstats_tags\x18\x01 \x03(\x0b\x32%.envoy.config.metrics.v2.TagSpecifier\x12\x38\n\x14use_all_default_tags\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12<\n\rstats_matcher\x18\x03 \x01(\x0b\x32%.envoy.config.metrics.v2.StatsMatcher\"\xbc\x01\n\x0cStatsMatcher\x12\x14\n\nreject_all\x18\x01 \x01(\x08H\x00\x12?\n\x0e\x65xclusion_list\x18\x02 \x01(\x0b\x32%.envoy.type.matcher.ListStringMatcherH\x00\x12?\n\x0einclusion_list\x18\x03 \x01(\x0b\x32%.envoy.type.matcher.ListStringMatcherH\x00\x42\x14\n\rstats_matcher\x12\x03\xf8\x42\x01\"_\n\x0cTagSpecifier\x12\x10\n\x08tag_name\x18\x01 \x01(\t\x12\x19\n\x05regex\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03(\x80\x08H\x00\x12\x15\n\x0b\x66ixed_value\x18\x03 \x01(\tH\x00\x42\x0b\n\ttag_value\"\x80\x01\n\nStatsdSink\x12-\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1a.envoy.api.v2.core.AddressH\x00\x12\x1a\n\x10tcp_cluster_name\x18\x02 \x01(\tH\x00\x12\x0e\n\x06prefix\x18\x03 \x01(\tB\x17\n\x10statsd_specifier\x12\x03\xf8\x42\x01\"q\n\rDogStatsdSink\x12-\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1a.envoy.api.v2.core.AddressH\x00\x12\x0e\n\x06prefix\x18\x03 \x01(\tB\x1b\n\x14\x64og_statsd_specifier\x12\x03\xf8\x42\x01J\x04\x08\x02\x10\x03\"\"\n\x0bHystrixSink\x12\x13\n\x0bnum_buckets\x18\x01 \x01(\x03\x42=\n%io.envoyproxy.envoy.config.metrics.v2B\nStatsProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_address__pb2.DESCRIPTOR,envoy_dot_type_dot_matcher_dot_string__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_STATSSINK = _descriptor.Descriptor(
  name='StatsSink',
  full_name='envoy.config.metrics.v2.StatsSink',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.metrics.v2.StatsSink.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='envoy.config.metrics.v2.StatsSink.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_config', full_name='envoy.config.metrics.v2.StatsSink.typed_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config_type', full_name='envoy.config.metrics.v2.StatsSink.config_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=276,
  serialized_end=409,
)


_STATSCONFIG = _descriptor.Descriptor(
  name='StatsConfig',
  full_name='envoy.config.metrics.v2.StatsConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stats_tags', full_name='envoy.config.metrics.v2.StatsConfig.stats_tags', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_all_default_tags', full_name='envoy.config.metrics.v2.StatsConfig.use_all_default_tags', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stats_matcher', full_name='envoy.config.metrics.v2.StatsConfig.stats_matcher', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=412,
  serialized_end=604,
)


_STATSMATCHER = _descriptor.Descriptor(
  name='StatsMatcher',
  full_name='envoy.config.metrics.v2.StatsMatcher',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reject_all', full_name='envoy.config.metrics.v2.StatsMatcher.reject_all', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exclusion_list', full_name='envoy.config.metrics.v2.StatsMatcher.exclusion_list', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inclusion_list', full_name='envoy.config.metrics.v2.StatsMatcher.inclusion_list', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='stats_matcher', full_name='envoy.config.metrics.v2.StatsMatcher.stats_matcher',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=607,
  serialized_end=795,
)


_TAGSPECIFIER = _descriptor.Descriptor(
  name='TagSpecifier',
  full_name='envoy.config.metrics.v2.TagSpecifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag_name', full_name='envoy.config.metrics.v2.TagSpecifier.tag_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='regex', full_name='envoy.config.metrics.v2.TagSpecifier.regex', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005r\003(\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fixed_value', full_name='envoy.config.metrics.v2.TagSpecifier.fixed_value', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='tag_value', full_name='envoy.config.metrics.v2.TagSpecifier.tag_value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=797,
  serialized_end=892,
)


_STATSDSINK = _descriptor.Descriptor(
  name='StatsdSink',
  full_name='envoy.config.metrics.v2.StatsdSink',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='envoy.config.metrics.v2.StatsdSink.address', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tcp_cluster_name', full_name='envoy.config.metrics.v2.StatsdSink.tcp_cluster_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prefix', full_name='envoy.config.metrics.v2.StatsdSink.prefix', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='statsd_specifier', full_name='envoy.config.metrics.v2.StatsdSink.statsd_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=895,
  serialized_end=1023,
)


_DOGSTATSDSINK = _descriptor.Descriptor(
  name='DogStatsdSink',
  full_name='envoy.config.metrics.v2.DogStatsdSink',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='envoy.config.metrics.v2.DogStatsdSink.address', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prefix', full_name='envoy.config.metrics.v2.DogStatsdSink.prefix', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='dog_statsd_specifier', full_name='envoy.config.metrics.v2.DogStatsdSink.dog_statsd_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=1025,
  serialized_end=1138,
)


_HYSTRIXSINK = _descriptor.Descriptor(
  name='HystrixSink',
  full_name='envoy.config.metrics.v2.HystrixSink',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='num_buckets', full_name='envoy.config.metrics.v2.HystrixSink.num_buckets', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1140,
  serialized_end=1174,
)

_STATSSINK.fields_by_name['config'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_STATSSINK.fields_by_name['typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_STATSSINK.oneofs_by_name['config_type'].fields.append(
  _STATSSINK.fields_by_name['config'])
_STATSSINK.fields_by_name['config'].containing_oneof = _STATSSINK.oneofs_by_name['config_type']
_STATSSINK.oneofs_by_name['config_type'].fields.append(
  _STATSSINK.fields_by_name['typed_config'])
_STATSSINK.fields_by_name['typed_config'].containing_oneof = _STATSSINK.oneofs_by_name['config_type']
_STATSCONFIG.fields_by_name['stats_tags'].message_type = _TAGSPECIFIER
_STATSCONFIG.fields_by_name['use_all_default_tags'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_STATSCONFIG.fields_by_name['stats_matcher'].message_type = _STATSMATCHER
_STATSMATCHER.fields_by_name['exclusion_list'].message_type = envoy_dot_type_dot_matcher_dot_string__pb2._LISTSTRINGMATCHER
_STATSMATCHER.fields_by_name['inclusion_list'].message_type = envoy_dot_type_dot_matcher_dot_string__pb2._LISTSTRINGMATCHER
_STATSMATCHER.oneofs_by_name['stats_matcher'].fields.append(
  _STATSMATCHER.fields_by_name['reject_all'])
_STATSMATCHER.fields_by_name['reject_all'].containing_oneof = _STATSMATCHER.oneofs_by_name['stats_matcher']
_STATSMATCHER.oneofs_by_name['stats_matcher'].fields.append(
  _STATSMATCHER.fields_by_name['exclusion_list'])
_STATSMATCHER.fields_by_name['exclusion_list'].containing_oneof = _STATSMATCHER.oneofs_by_name['stats_matcher']
_STATSMATCHER.oneofs_by_name['stats_matcher'].fields.append(
  _STATSMATCHER.fields_by_name['inclusion_list'])
_STATSMATCHER.fields_by_name['inclusion_list'].containing_oneof = _STATSMATCHER.oneofs_by_name['stats_matcher']
_TAGSPECIFIER.oneofs_by_name['tag_value'].fields.append(
  _TAGSPECIFIER.fields_by_name['regex'])
_TAGSPECIFIER.fields_by_name['regex'].containing_oneof = _TAGSPECIFIER.oneofs_by_name['tag_value']
_TAGSPECIFIER.oneofs_by_name['tag_value'].fields.append(
  _TAGSPECIFIER.fields_by_name['fixed_value'])
_TAGSPECIFIER.fields_by_name['fixed_value'].containing_oneof = _TAGSPECIFIER.oneofs_by_name['tag_value']
_STATSDSINK.fields_by_name['address'].message_type = envoy_dot_api_dot_v2_dot_core_dot_address__pb2._ADDRESS
_STATSDSINK.oneofs_by_name['statsd_specifier'].fields.append(
  _STATSDSINK.fields_by_name['address'])
_STATSDSINK.fields_by_name['address'].containing_oneof = _STATSDSINK.oneofs_by_name['statsd_specifier']
_STATSDSINK.oneofs_by_name['statsd_specifier'].fields.append(
  _STATSDSINK.fields_by_name['tcp_cluster_name'])
_STATSDSINK.fields_by_name['tcp_cluster_name'].containing_oneof = _STATSDSINK.oneofs_by_name['statsd_specifier']
_DOGSTATSDSINK.fields_by_name['address'].message_type = envoy_dot_api_dot_v2_dot_core_dot_address__pb2._ADDRESS
_DOGSTATSDSINK.oneofs_by_name['dog_statsd_specifier'].fields.append(
  _DOGSTATSDSINK.fields_by_name['address'])
_DOGSTATSDSINK.fields_by_name['address'].containing_oneof = _DOGSTATSDSINK.oneofs_by_name['dog_statsd_specifier']
DESCRIPTOR.message_types_by_name['StatsSink'] = _STATSSINK
DESCRIPTOR.message_types_by_name['StatsConfig'] = _STATSCONFIG
DESCRIPTOR.message_types_by_name['StatsMatcher'] = _STATSMATCHER
DESCRIPTOR.message_types_by_name['TagSpecifier'] = _TAGSPECIFIER
DESCRIPTOR.message_types_by_name['StatsdSink'] = _STATSDSINK
DESCRIPTOR.message_types_by_name['DogStatsdSink'] = _DOGSTATSDSINK
DESCRIPTOR.message_types_by_name['HystrixSink'] = _HYSTRIXSINK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StatsSink = _reflection.GeneratedProtocolMessageType('StatsSink', (_message.Message,), {
  'DESCRIPTOR' : _STATSSINK,
  '__module__' : 'envoy.config.metrics.v2.stats_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.metrics.v2.StatsSink)
  })
_sym_db.RegisterMessage(StatsSink)

StatsConfig = _reflection.GeneratedProtocolMessageType('StatsConfig', (_message.Message,), {
  'DESCRIPTOR' : _STATSCONFIG,
  '__module__' : 'envoy.config.metrics.v2.stats_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.metrics.v2.StatsConfig)
  })
_sym_db.RegisterMessage(StatsConfig)

StatsMatcher = _reflection.GeneratedProtocolMessageType('StatsMatcher', (_message.Message,), {
  'DESCRIPTOR' : _STATSMATCHER,
  '__module__' : 'envoy.config.metrics.v2.stats_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.metrics.v2.StatsMatcher)
  })
_sym_db.RegisterMessage(StatsMatcher)

TagSpecifier = _reflection.GeneratedProtocolMessageType('TagSpecifier', (_message.Message,), {
  'DESCRIPTOR' : _TAGSPECIFIER,
  '__module__' : 'envoy.config.metrics.v2.stats_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.metrics.v2.TagSpecifier)
  })
_sym_db.RegisterMessage(TagSpecifier)

StatsdSink = _reflection.GeneratedProtocolMessageType('StatsdSink', (_message.Message,), {
  'DESCRIPTOR' : _STATSDSINK,
  '__module__' : 'envoy.config.metrics.v2.stats_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.metrics.v2.StatsdSink)
  })
_sym_db.RegisterMessage(StatsdSink)

DogStatsdSink = _reflection.GeneratedProtocolMessageType('DogStatsdSink', (_message.Message,), {
  'DESCRIPTOR' : _DOGSTATSDSINK,
  '__module__' : 'envoy.config.metrics.v2.stats_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.metrics.v2.DogStatsdSink)
  })
_sym_db.RegisterMessage(DogStatsdSink)

HystrixSink = _reflection.GeneratedProtocolMessageType('HystrixSink', (_message.Message,), {
  'DESCRIPTOR' : _HYSTRIXSINK,
  '__module__' : 'envoy.config.metrics.v2.stats_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.metrics.v2.HystrixSink)
  })
_sym_db.RegisterMessage(HystrixSink)


DESCRIPTOR._options = None
_STATSSINK.fields_by_name['config']._options = None
_STATSMATCHER.oneofs_by_name['stats_matcher']._options = None
_TAGSPECIFIER.fields_by_name['regex']._options = None
_STATSDSINK.oneofs_by_name['statsd_specifier']._options = None
_DOGSTATSDSINK.oneofs_by_name['dog_statsd_specifier']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/auth/v2alpha/external_auth.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.service.auth.v2 import external_auth_pb2 as envoy_dot_service_dot_auth_dot_v2_dot_external__auth__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/service/auth/v2alpha/external_auth.proto',
  package='envoy.service.auth.v2alpha',
  syntax='proto3',
  serialized_options=b'\n(io.envoyproxy.envoy.service.auth.v2alphaB\nCertsProtoP\001\210\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.envoy/service/auth/v2alpha/external_auth.proto\x12\x1a\x65nvoy.service.auth.v2alpha\x1a)envoy/service/auth/v2/external_auth.proto2c\n\rAuthorization\x12R\n\x05\x43heck\x12#.envoy.service.auth.v2.CheckRequest\x1a$.envoy.service.auth.v2.CheckResponseB;\n(io.envoyproxy.envoy.service.auth.v2alphaB\nCertsProtoP\x01\x88\x01\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_service_dot_auth_dot_v2_dot_external__auth__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_AUTHORIZATION = _descriptor.ServiceDescriptor(
  name='Authorization',
  full_name='envoy.service.auth.v2alpha.Authorization',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=121,
  serialized_end=220,
  methods=[
  _descriptor.MethodDescriptor(
    name='Check',
    full_name='envoy.service.auth.v2alpha.Authorization.Check',
    index=0,
    containing_service=None,
    input_type=envoy_dot_service_dot_auth_dot_v2_dot_external__auth__pb2._CHECKREQUEST,
    output_type=envoy_dot_service_dot_auth_dot_v2_dot_external__auth__pb2._CHECKRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_AUTHORIZATION)

DESCRIPTOR.services_by_name['Authorization'] = _AUTHORIZATION

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/router/v3/router.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.accesslog.v3 import accesslog_pb2 as envoy_dot_config_dot_accesslog_dot_v3_dot_accesslog__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/router/v3/router.proto',
  package='envoy.extensions.filters.http.router.v3',
  syntax='proto3',
  serialized_options=b'\n5io.envoyproxy.envoy.extensions.filters.http.router.v3B\013RouterProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4envoy/extensions/filters/http/router/v3/router.proto\x12\'envoy.extensions.filters.http.router.v3\x1a)envoy/config/accesslog/v3/accesslog.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xbe\x03\n\x06Router\x12\x31\n\rdynamic_stats\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x18\n\x10start_child_span\x18\x02 \x01(\x08\x12:\n\x0cupstream_log\x18\x03 \x03(\x0b\x32$.envoy.config.accesslog.v3.AccessLog\x12\x1e\n\x16suppress_envoy_headers\x18\x04 \x01(\x08\x12\xb3\x01\n\x14strict_check_headers\x18\x05 \x03(\tB\x94\x01\xfa\x42\x90\x01\x92\x01\x8c\x01\"\x89\x01r\x86\x01R\x1ex-envoy-upstream-rq-timeout-msR&x-envoy-upstream-rq-per-try-timeout-msR\x13x-envoy-max-retriesR\x15x-envoy-retry-grpc-onR\x10x-envoy-retry-on\x12#\n\x1brespect_expected_rq_timeout\x18\x06 \x01(\x08:0\x9a\xc5\x88\x1e+\n)envoy.config.filter.http.router.v2.RouterBN\n5io.envoyproxy.envoy.extensions.filters.http.router.v3B\x0bRouterProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_accesslog_dot_v3_dot_accesslog__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_ROUTER = _descriptor.Descriptor(
  name='Router',
  full_name='envoy.extensions.filters.http.router.v3.Router',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dynamic_stats', full_name='envoy.extensions.filters.http.router.v3.Router.dynamic_stats', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_child_span', full_name='envoy.extensions.filters.http.router.v3.Router.start_child_span', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upstream_log', full_name='envoy.extensions.filters.http.router.v3.Router.upstream_log', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='suppress_envoy_headers', full_name='envoy.extensions.filters.http.router.v3.Router.suppress_envoy_headers', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strict_check_headers', full_name='envoy.extensions.filters.http.router.v3.Router.strict_check_headers', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\220\001\222\001\214\001\"\211\001r\206\001R\036x-envoy-upstream-rq-timeout-msR&x-envoy-upstream-rq-per-try-timeout-msR\023x-envoy-max-retriesR\025x-envoy-retry-grpc-onR\020x-envoy-retry-on', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='respect_expected_rq_timeout', full_name='envoy.extensions.filters.http.router.v3.Router.respect_expected_rq_timeout', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036+\n)envoy.config.filter.http.router.v2.Router',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=264,
  serialized_end=710,
)

_ROUTER.fields_by_name['dynamic_stats'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_ROUTER.fields_by_name['upstream_log'].message_type = envoy_dot_config_dot_accesslog_dot_v3_dot_accesslog__pb2._ACCESSLOG
DESCRIPTOR.message_types_by_name['Router'] = _ROUTER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Router = _reflection.GeneratedProtocolMessageType('Router', (_message.Message,), {
  'DESCRIPTOR' : _ROUTER,
  '__module__' : 'envoy.extensions.filters.http.router.v3.router_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.router.v3.Router)
  })
_sym_db.RegisterMessage(Router)


DESCRIPTOR._options = None
_ROUTER.fields_by_name['strict_check_headers']._options = None
_ROUTER._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/auth/v3/attribute_context.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import address_pb2 as envoy_dot_config_dot_core_dot_v3_dot_address__pb2
from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/service/auth/v3/attribute_context.proto',
  package='envoy.service.auth.v3',
  syntax='proto3',
  serialized_options=b'\n#io.envoyproxy.envoy.service.auth.v3B\025AttributeContextProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-envoy/service/auth/v3/attribute_context.proto\x12\x15\x65nvoy.service.auth.v3\x1a\"envoy/config/core/v3/address.proto\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"\x9a\n\n\x10\x41ttributeContext\x12<\n\x06source\x18\x01 \x01(\x0b\x32,.envoy.service.auth.v3.AttributeContext.Peer\x12\x41\n\x0b\x64\x65stination\x18\x02 \x01(\x0b\x32,.envoy.service.auth.v3.AttributeContext.Peer\x12@\n\x07request\x18\x04 \x01(\x0b\x32/.envoy.service.auth.v3.AttributeContext.Request\x12Z\n\x12\x63ontext_extensions\x18\n \x03(\x0b\x32>.envoy.service.auth.v3.AttributeContext.ContextExtensionsEntry\x12\x38\n\x10metadata_context\x18\x0b \x01(\x0b\x32\x1e.envoy.config.core.v3.Metadata\x1a\x9c\x02\n\x04Peer\x12.\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1d.envoy.config.core.v3.Address\x12\x0f\n\x07service\x18\x02 \x01(\t\x12H\n\x06labels\x18\x03 \x03(\x0b\x32\x38.envoy.service.auth.v3.AttributeContext.Peer.LabelsEntry\x12\x11\n\tprincipal\x18\x04 \x01(\t\x12\x13\n\x0b\x63\x65rtificate\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01:2\x9a\xc5\x88\x1e-\n+envoy.service.auth.v2.AttributeContext.Peer\x1a\xad\x01\n\x07Request\x12(\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x41\n\x04http\x18\x02 \x01(\x0b\x32\x33.envoy.service.auth.v3.AttributeContext.HttpRequest:5\x9a\xc5\x88\x1e\x30\n.envoy.service.auth.v2.AttributeContext.Request\x1a\xf4\x02\n\x0bHttpRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06method\x18\x02 \x01(\t\x12Q\n\x07headers\x18\x03 \x03(\x0b\x32@.envoy.service.auth.v3.AttributeContext.HttpRequest.HeadersEntry\x12\x0c\n\x04path\x18\x04 \x01(\t\x12\x0c\n\x04host\x18\x05 \x01(\t\x12\x0e\n\x06scheme\x18\x06 \x01(\t\x12\r\n\x05query\x18\x07 \x01(\t\x12\x10\n\x08\x66ragment\x18\x08 \x01(\t\x12\x0c\n\x04size\x18\t \x01(\x03\x12\x10\n\x08protocol\x18\n \x01(\t\x12\x0c\n\x04\x62ody\x18\x0b \x01(\t\x12\x10\n\x08raw_body\x18\x0c \x01(\x0c\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01:9\x9a\xc5\x88\x1e\x34\n2envoy.service.auth.v2.AttributeContext.HttpRequest\x1a\x38\n\x16\x43ontextExtensionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01:-\x9a\xc5\x88\x1e(\n&envoy.service.auth.v2.AttributeContextBF\n#io.envoyproxy.envoy.service.auth.v3B\x15\x41ttributeContextProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_address__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v3_dot_base__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,])




_ATTRIBUTECONTEXT_PEER_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='envoy.service.auth.v3.AttributeContext.Peer.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.service.auth.v3.AttributeContext.Peer.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.service.auth.v3.AttributeContext.Peer.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=794,
  serialized_end=839,
)

_ATTRIBUTECONTEXT_PEER = _descriptor.Descriptor(
  name='Peer',
  full_name='envoy.service.auth.v3.AttributeContext.Peer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='envoy.service.auth.v3.AttributeContext.Peer.address', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service', full_name='envoy.service.auth.v3.AttributeContext.Peer.service', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='envoy.service.auth.v3.AttributeContext.Peer.labels', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='principal', full_name='envoy.service.auth.v3.AttributeContext.Peer.principal', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='certificate', full_name='envoy.service.auth.v3.AttributeContext.Peer.certificate', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ATTRIBUTECONTEXT_PEER_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036-\n+envoy.service.auth.v2.AttributeContext.Peer',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=607,
  serialized_end=891,
)

_ATTRIBUTECONTEXT_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='envoy.service.auth.v3.AttributeContext.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='envoy.service.auth.v3.AttributeContext.Request.time', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http', full_name='envoy.service.auth.v3.AttributeContext.Request.http', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0360\n.envoy.service.auth.v2.AttributeContext.Request',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=894,
  serialized_end=1067,
)

_ATTRIBUTECONTEXT_HTTPREQUEST_HEADERSENTRY = _descriptor.Descriptor(
  name='HeadersEntry',
  full_name='envoy.service.auth.v3.AttributeContext.HttpRequest.HeadersEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.service.auth.v3.AttributeContext.HttpRequest.HeadersEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.service.auth.v3.AttributeContext.HttpRequest.HeadersEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1337,
  serialized_end=1383,
)

_ATTRIBUTECONTEXT_HTTPREQUEST = _descriptor.Descriptor(
  name='HttpRequest',
  full_name='envoy.service.auth.v3.AttributeContext.HttpRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='envoy.service.auth.v3.AttributeContext.HttpRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='method', full_name='envoy.service.auth.v3.AttributeContext.HttpRequest.method', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headers', full_name='envoy.service.auth.v3.AttributeContext.HttpRequest.headers', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='envoy.service.auth.v3.AttributeContext.HttpRequest.path', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host', full_name='envoy.service.auth.v3.AttributeContext.HttpRequest.host', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scheme', full_name='envoy.service.auth.v3.AttributeContext.HttpRequest.scheme', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query', full_name='envoy.service.auth.v3.AttributeContext.HttpRequest.query', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fragment', full_name='envoy.service.auth.v3.AttributeContext.HttpRequest.fragment', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='envoy.service.auth.v3.AttributeContext.HttpRequest.size', index=8,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='envoy.service.auth.v3.AttributeContext.HttpRequest.protocol', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body', full_name='envoy.service.auth.v3.AttributeContext.HttpRequest.body', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_body', full_name='envoy.service.auth.v3.AttributeContext.HttpRequest.raw_body', index=11,
      number=12, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ATTRIBUTECONTEXT_HTTPREQUEST_HEADERSENTRY, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0364\n2envoy.service.auth.v2.AttributeContext.HttpRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1070,
  serialized_end=1442,
)

_ATTRIBUTECONTEXT_CONTEXTEXTENSIONSENTRY = _descriptor.Descriptor(
  name='ContextExtensionsEntry',
  full_name='envoy.service.auth.v3.AttributeContext.ContextExtensionsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.service.auth.v3.AttributeContext.ContextExtensionsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.service.auth.v3.AttributeContext.ContextExtensionsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1444,
  serialized_end=1500,
)

_ATTRIBUTECONTEXT = _descriptor.Descriptor(
  name='AttributeContext',
  full_name='envoy.service.auth.v3.AttributeContext',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source', full_name='envoy.service.auth.v3.AttributeContext.source', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination', full_name='envoy.service.auth.v3.AttributeContext.destination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request', full_name='envoy.service.auth.v3.AttributeContext.request', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='context_extensions', full_name='envoy.service.auth.v3.AttributeContext.context_extensions', index=3,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata_context', full_name='envoy.service.auth.v3.AttributeContext.metadata_context', index=4,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ATTRIBUTECONTEXT_PEER, _ATTRIBUTECONTEXT_REQUEST, _ATTRIBUTECONTEXT_HTTPREQUEST, _ATTRIBUTECONTEXT_CONTEXTEXTENSIONSENTRY, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036(\n&envoy.service.auth.v2.AttributeContext',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=241,
  serialized_end=1547,
)

_ATTRIBUTECONTEXT_PEER_LABELSENTRY.containing_type = _ATTRIBUTECONTEXT_PEER
_ATTRIBUTECONTEXT_PEER.fields_by_name['address'].message_type = envoy_dot_config_dot_core_dot_v3_dot_address__pb2._ADDRESS
_ATTRIBUTECONTEXT_PEER.fields_by_name['labels'].message_type = _ATTRIBUTECONTEXT_PEER_LABELSENTRY
_ATTRIBUTECONTEXT_PEER.containing_type = _ATTRIBUTECONTEXT
_ATTRIBUTECONTEXT_REQUEST.fields_by_name['time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ATTRIBUTECONTEXT_REQUEST.fields_by_name['http'].message_type = _ATTRIBUTECONTEXT_HTTPREQUEST
_ATTRIBUTECONTEXT_REQUEST.containing_type = _ATTRIBUTECONTEXT
_ATTRIBUTECONTEXT_HTTPREQUEST_HEADERSENTRY.containing_type = _ATTRIBUTECONTEXT_HTTPREQUEST
_ATTRIBUTECONTEXT_HTTPREQUEST.fields_by_name['headers'].message_type = _ATTRIBUTECONTEXT_HTTPREQUEST_HEADERSENTRY
_ATTRIBUTECONTEXT_HTTPREQUEST.containing_type = _ATTRIBUTECONTEXT
_ATTRIBUTECONTEXT_CONTEXTEXTENSIONSENTRY.containing_type = _ATTRIBUTECONTEXT
_ATTRIBUTECONTEXT.fields_by_name['source'].message_type = _ATTRIBUTECONTEXT_PEER
_ATTRIBUTECONTEXT.fields_by_name['destination'].message_type = _ATTRIBUTECONTEXT_PEER
_ATTRIBUTECONTEXT.fields_by_name['request'].message_type = _ATTRIBUTECONTEXT_REQUEST
_ATTRIBUTECONTEXT.fields_by_name['context_extensions'].message_type = _ATTRIBUTECONTEXT_CONTEXTEXTENSIONSENTRY
_ATTRIBUTECONTEXT.fields_by_name['metadata_context'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._METADATA
DESCRIPTOR.message_types_by_name['AttributeContext'] = _ATTRIBUTECONTEXT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AttributeContext = _reflection.GeneratedProtocolMessageType('AttributeContext', (_message.Message,), {

  'Peer' : _reflection.GeneratedProtocolMessageType('Peer', (_message.Message,), {

    'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
      'DESCRIPTOR' : _ATTRIBUTECONTEXT_PEER_LABELSENTRY,
      '__module__' : 'envoy.service.auth.v3.attribute_context_pb2'
      # @@protoc_insertion_point(class_scope:envoy.service.auth.v3.AttributeContext.Peer.LabelsEntry)
      })
    ,
    'DESCRIPTOR' : _ATTRIBUTECONTEXT_PEER,
    '__module__' : 'envoy.service.auth.v3.attribute_context_pb2'
    # @@protoc_insertion_point(class_scope:envoy.service.auth.v3.AttributeContext.Peer)
    })
  ,

  'Request' : _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
    'DESCRIPTOR' : _ATTRIBUTECONTEXT_REQUEST,
    '__module__' : 'envoy.service.auth.v3.attribute_context_pb2'
    # @@protoc_insertion_point(class_scope:envoy.service.auth.v3.AttributeContext.Request)
    })
  ,

  'HttpRequest' : _reflection.GeneratedProtocolMessageType('HttpRequest', (_message.Message,), {

    'HeadersEntry' : _reflection.GeneratedProtocolMessageType('HeadersEntry', (_message.Message,), {
      'DESCRIPTOR' : _ATTRIBUTECONTEXT_HTTPREQUEST_HEADERSENTRY,
      '__module__' : 'envoy.service.auth.v3.attribute_context_pb2'
      # @@protoc_insertion_point(class_scope:envoy.service.auth.v3.AttributeContext.HttpRequest.HeadersEntry)
      })
    ,
    'DESCRIPTOR' : _ATTRIBUTECONTEXT_HTTPREQUEST,
    '__module__' : 'envoy.service.auth.v3.attribute_context_pb2'
    # @@protoc_insertion_point(class_scope:envoy.service.auth.v3.AttributeContext.HttpRequest)
    })
  ,

  'ContextExtensionsEntry' : _reflection.GeneratedProtocolMessageType('ContextExtensionsEntry', (_message.Message,), {
    'DESCRIPTOR' : _ATTRIBUTECONTEXT_CONTEXTEXTENSIONSENTRY,
    '__module__' : 'envoy.service.auth.v3.attribute_context_pb2'
    # @@protoc_insertion_point(class_scope:envoy.service.auth.v3.AttributeContext.ContextExtensionsEntry)
    })
  ,
  'DESCRIPTOR' : _ATTRIBUTECONTEXT,
  '__module__' : 'envoy.service.auth.v3.attribute_context_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.auth.v3.AttributeContext)
  })
_sym_db.RegisterMessage(AttributeContext)
_sym_db.RegisterMessage(AttributeContext.Peer)
_sym_db.RegisterMessage(AttributeContext.Peer.LabelsEntry)
_sym_db.RegisterMessage(AttributeContext.Request)
_sym_db.RegisterMessage(AttributeContext.HttpRequest)
_sym_db.RegisterMessage(AttributeContext.HttpRequest.HeadersEntry)
_sym_db.RegisterMessage(AttributeContext.ContextExtensionsEntry)


DESCRIPTOR._options = None
_ATTRIBUTECONTEXT_PEER_LABELSENTRY._options = None
_ATTRIBUTECONTEXT_PEER._options = None
_ATTRIBUTECONTEXT_REQUEST._options = None
_ATTRIBUTECONTEXT_HTTPREQUEST_HEADERSENTRY._options = None
_ATTRIBUTECONTEXT_HTTPREQUEST._options = None
_ATTRIBUTECONTEXT_CONTEXTEXTENSIONSENTRY._options = None
_ATTRIBUTECONTEXT._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/retry/omit_host_metadata/v2/omit_host_metadata_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/retry/omit_host_metadata/v2/omit_host_metadata_config.proto',
  package='envoy.config.retry.omit_host_metadata.v2',
  syntax='proto3',
  serialized_options=b'\n6io.envoyproxy.envoy.config.retry.omit_host_metadata.v2B\033OmitHostMetadataConfigProtoP\001\362\230\376\217\0053\0221envoy.extensions.retry.host.omit_host_metadata.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nHenvoy/config/retry/omit_host_metadata/v2/omit_host_metadata_config.proto\x12(envoy.config.retry.omit_host_metadata.v2\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\"M\n\x16OmitHostMetadataConfig\x12\x33\n\x0emetadata_match\x18\x01 \x01(\x0b\x32\x1b.envoy.api.v2.core.MetadataB\x98\x01\n6io.envoyproxy.envoy.config.retry.omit_host_metadata.v2B\x1bOmitHostMetadataConfigProtoP\x01\xf2\x98\xfe\x8f\x05\x33\x12\x31\x65nvoy.extensions.retry.host.omit_host_metadata.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_OMITHOSTMETADATACONFIG = _descriptor.Descriptor(
  name='OmitHostMetadataConfig',
  full_name='envoy.config.retry.omit_host_metadata.v2.OmitHostMetadataConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata_match', full_name='envoy.config.retry.omit_host_metadata.v2.OmitHostMetadataConfig.metadata_match', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=211,
  serialized_end=288,
)

_OMITHOSTMETADATACONFIG.fields_by_name['metadata_match'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._METADATA
DESCRIPTOR.message_types_by_name['OmitHostMetadataConfig'] = _OMITHOSTMETADATACONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OmitHostMetadataConfig = _reflection.GeneratedProtocolMessageType('OmitHostMetadataConfig', (_message.Message,), {
  'DESCRIPTOR' : _OMITHOSTMETADATACONFIG,
  '__module__' : 'envoy.config.retry.omit_host_metadata.v2.omit_host_metadata_config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.retry.omit_host_metadata.v2.OmitHostMetadataConfig)
  })
_sym_db.RegisterMessage(OmitHostMetadataConfig)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/http/compressor/v2/compressor.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/filter/http/compressor/v2/compressor.proto',
  package='envoy.config.filter.http.compressor.v2',
  syntax='proto3',
  serialized_options=b'\n4io.envoyproxy.envoy.config.filter.http.compressor.v2B\017CompressorProtoP\001\362\230\376\217\005-\022+envoy.extensions.filters.http.compressor.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n7envoy/config/filter/http/compressor/v2/compressor.proto\x12&envoy.config.filter.http.compressor.v2\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\"\xdf\x01\n\nCompressor\x12\x34\n\x0e\x63ontent_length\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x14\n\x0c\x63ontent_type\x18\x02 \x03(\t\x12\x1e\n\x16\x64isable_on_etag_header\x18\x03 \x01(\x08\x12%\n\x1dremove_accept_encoding_header\x18\x04 \x01(\x08\x12>\n\x0fruntime_enabled\x18\x05 \x01(\x0b\x32%.envoy.api.v2.core.RuntimeFeatureFlagB\x84\x01\n4io.envoyproxy.envoy.config.filter.http.compressor.v2B\x0f\x43ompressorProtoP\x01\xf2\x98\xfe\x8f\x05-\x12+envoy.extensions.filters.http.compressor.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_COMPRESSOR = _descriptor.Descriptor(
  name='Compressor',
  full_name='envoy.config.filter.http.compressor.v2.Compressor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content_length', full_name='envoy.config.filter.http.compressor.v2.Compressor.content_length', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content_type', full_name='envoy.config.filter.http.compressor.v2.Compressor.content_type', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disable_on_etag_header', full_name='envoy.config.filter.http.compressor.v2.Compressor.disable_on_etag_header', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remove_accept_encoding_header', full_name='envoy.config.filter.http.compressor.v2.Compressor.remove_accept_encoding_header', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runtime_enabled', full_name='envoy.config.filter.http.compressor.v2.Compressor.runtime_enabled', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=225,
  serialized_end=448,
)

_COMPRESSOR.fields_by_name['content_length'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_COMPRESSOR.fields_by_name['runtime_enabled'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._RUNTIMEFEATUREFLAG
DESCRIPTOR.message_types_by_name['Compressor'] = _COMPRESSOR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Compressor = _reflection.GeneratedProtocolMessageType('Compressor', (_message.Message,), {
  'DESCRIPTOR' : _COMPRESSOR,
  '__module__' : 'envoy.config.filter.http.compressor.v2.compressor_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.compressor.v2.Compressor)
  })
_sym_db.RegisterMessage(Compressor)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
